@@ -32,11 +32,19 @@ class Client(object):
             },
             workspaceId=workspaceId
         )
-    def use_saved_query(self, name):
-        query = self.workspace.saved_query.get(name)
+    def use_saved_query(self, title):
+        query = self.workspace.saved_query.get(title)
         return self.execute(query['sql'])
     def list_saved_query(self):
-        return self.workspace.saved_query.list()
+        return self.workspace.saved_query.list_title()
+    def list_file(self):
+        return self.workspace.file.list_absolute_path()
+    def get_binary(self, absolutePath):
+        return self.workspace.file.get_content(absolutePath)
+    def get_csv(self, absolutePath):
+        return self.workspace.file.get_csv(absolutePath)
+    def get_json(self, absolutePath):
+        return self.workspace.file.get_json(absolutePath)
     def execute(self, sql):
         cursor = self.workspace.statement.execute(sql);
         return cursor
