@@ -28,10 +28,13 @@ class SavedQuery(object):
                 }
             }
         }
-    def list(self):
+    def fetch(self):
         return self.request.post(self.getPayload()).get('sqls')
-    def get(self, name):
-        queries = self.list()
-        query = next(q for q in queries if q.get('title') == name)
+    def list_title(self):
+        data = self.fetch()
+        return list(map(lambda x: x['title'], data))
+    def get(self, title):
+        queries = self.fetch()
+        query = next(q for q in queries if q.get('title') == title)
         return  query
 
