@@ -1,6 +1,7 @@
 from cannerflow.request import Request
 from cannerflow.saved_query import SavedQuery
 from cannerflow.statement import Statement
+from cannerflow.file import File
 
 __all__ = ["Workspace"]
 
@@ -26,4 +27,8 @@ class Workspace(object):
         self.statement = Statement(
             request=request,
             workspaceId=workspaceId
+        )
+        self.file = File(
+            request=request,
+            workspaceId=workspaceId
         )
\ No newline at end of file
